@@ -30,9 +30,6 @@ class Theme;
 
 // NOTE: Default wallpaper can be set from the theme configuration
 #define DEFAULT_WALLPAPER_THEME "default"
-#define DEFAULT_WALLPAPER_SUFFIX ".png"
-static const int DEFAULT_WALLPAPER_WIDTH = 1920;
-static const int DEFAULT_WALLPAPER_HEIGHT = 1200;
 
 class ThemePrivate : public QObject, public QSharedData
 {
@@ -44,8 +41,6 @@ public:
 
     KConfigGroup &config();
 
-    QString imagePath(const QString &theme, const QString &type, const QString &image);
-    QString findInTheme(const QString &image, const QString &theme);
     void scheduleThemeChangeNotification();
     void setThemeName(const QString &themeName, bool writeSettings, bool emitChanged);
     void processWallpaperSettings(const KSharedConfigPtr &metadata);
@@ -53,7 +48,7 @@ public:
     void processAdaptiveTransparencySettings(const KSharedConfigPtr &metadata);
     void processBlurBehindSettings(const KSharedConfigPtr &metadata);
 
-    QColor color(Theme::ColorRole role, Theme::ColorGroup group = Theme::NormalColorGroup) const;
+    QColor color(Theme::ColorRole role, Kirigami::Platform::PlatformTheme::ColorSet group) const;
 
     void updateKSvgSelectors();
 
@@ -64,9 +59,6 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void themeChanged();
-    void defaultFontChanged();
-    void smallestFontChanged();
-    void applicationPaletteChange();
 
 public:
     static const char defaultTheme[];
@@ -94,9 +86,6 @@ public:
     KConfigGroup cfg;
     KConfigWatcher::Ptr plasmaRcWatcher;
     QString defaultWallpaperTheme;
-    QString defaultWallpaperSuffix;
-    int defaultWallpaperWidth;
-    int defaultWallpaperHeight;
     QTimer *selectorsUpdateTimer;
     QTimer *updateNotificationTimer;
 
@@ -104,7 +93,6 @@ public:
     bool backgroundContrastActive : 1;
     bool isDefault : 1;
     bool useGlobal : 1;
-    bool hasWallpapers : 1;
     bool fixedName : 1;
 
     qreal backgroundContrast;
