@@ -6,10 +6,11 @@
 
 #pragma once
 
+#include <plasmaquick_export.h>
+
 #include "sharedqmlengine.h"
 
 #include <QQmlContext>
-#include <qstringlistmodel.h>
 
 namespace Plasma
 {
@@ -19,7 +20,7 @@ class Applet;
 namespace PlasmaQuick
 {
 
-class AppletContext : public QQmlContext
+class PLASMAQUICK_EXPORT AppletContext : public QQmlContext
 {
     Q_OBJECT
 public:
